@@ -1,14 +1,15 @@
-from fedbase.utils.data_loader import data_process
+from fedbase.utils.data_loader import data_process, log
 from fedbase.nodes.node import node
 from fedbase.server.server import server_class
 import torch
 from torch.utils.data import DataLoader
 import torch.optim as optim
+import os
 
 
 def fedavg(dir, dataset, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_epochs, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
     dt = data_process(dir, dataset)
-    train_splited,test_splited = dt.split_dataset(num_nodes, 2, method='class')
+    train_splited,test_splited = dt.split_dataset(num_nodes, 0.1)
 
     server = server_class()
     server.assign_model(model(), device)
@@ -43,4 +44,7 @@ def fedavg(dir, dataset, batch_size, num_nodes, model, objective, optimizer, glo
             nodes[j].local_test(device)
         # server aggregation and distribution
         server.aggregate(nodes, list(range(num_nodes)), device)
-        server.distribute(nodes, list(range(num_nodes)))
\ No newline at end of file
+        server.distribute(nodes, list(range(num_nodes)))
+
+    # log
+    log(os.path.basename(__file__)[:-3], nodes, server)
\ No newline at end of file
